@@ -14,7 +14,8 @@ from __future__ import unicode_literals
 import copy
 from decimal import Decimal as D, ROUND_CEILING
 
-from .constants3 import METRICS_ABBREVIATIONS, METRICS_MANDATORY, METRICS_VALUES
+from .constants3 import METRICS_ABBREVIATIONS, METRICS_MANDATORY, METRICS_VALUES, \
+    METRICS_VALUE_NAMES
 from .exceptions import CVSS3MalformedError, CVSS3MandatoryError, CVSS3RHMalformedError, \
     CVSS3RHScoreDoesNotMatch
 
@@ -195,6 +196,14 @@ class CVSS3(object):
             result = METRICS_VALUES[abbreviation][string_value]
         return result
 
+    def get_value_description(self, abbreviation):
+        """
+        Gets textual description of specific metric specified by its abbreviation.
+        """
+        string_value = self.metrics.get(abbreviation, 'X')
+        result = METRICS_VALUE_NAMES[abbreviation][string_value]
+        return result
+
     def compute_isc_base(self):
         """
         ISCBase = 1 - [(1-ImpactConf) x (1-ImpactInteg) x (1-ImpactAvail)]
@@ -399,3 +408,65 @@ class CVSS3(object):
 
     def __hash__(self):
         return hash(self.clean_vector())
+
+    def as_json(self):
+        """
+        Returns a dictionary formatted with attribute names and values defined by the official
+        CVSS JSON schema:
+
+        CVSS v3.0: https://www.first.org/cvss/cvss-v3.0.json?20170531
+        CVSS v3.1: https://www.first.org/cvss/cvss-v3.1.json?20190610
+
+        Serialize a `cvss` instance to JSON with:
+
+        json.dumps(cvss.as_json())
+
+        Returns:
+            (dict): JSON schema-compatible CVSS representation
+        """
+        def us(text):
+            # If this is the (modified) attack vector description, convert it from "adjacent" to
+            # "adjacent network" as defined by the schema.
+            if text == 'Adjacent':
+                return 'ADJACENT_NETWORK'
+            # Uppercase and convert to snake case
+            return text.upper().replace('-', '_').replace(' ', '_')
+
+        base_severity, temporal_severity, environmental_everity = self.severities()
+        return {
+            # Meta
+            'version': '3.' + str(self.minor_version),
+            # Vector
+            'vectorString': self.vector,
+            # Metrics
+            'attackVector': us(self.get_value_description('AV')),
+            'attackComplexity': us(self.get_value_description('AC')),
+            'privilegesRequired': us(self.get_value_description('PR')),
+            'userInteraction': us(self.get_value_description('UI')),
+            'scope': us(self.get_value_description('S')),
+            'confidentialityImpact': us(self.get_value_description('C')),
+            'integrityImpact': us(self.get_value_description('I')),
+            'availabilityImpact': us(self.get_value_description('A')),
+            'exploitCodeMaturity': us(self.get_value_description('E')),
+            'remediationLevel': us(self.get_value_description('RL')),
+            'reportConfidence': us(self.get_value_description('RC')),
+            'confidentialityRequirement': us(self.get_value_description('CR')),
+            'integrityRequirement': us(self.get_value_description('IR')),
+            'availabilityRequirement': us(self.get_value_description('AR')),
+            'modifiedAttackVector': us(self.get_value_description('MAV')),
+            'modifiedAttackComplexity': us(self.get_value_description('MAC')),
+            'modifiedPrivilegesRequired': us(self.get_value_description('MPR')),
+            'modifiedUserInteraction': us(self.get_value_description('MUI')),
+            'modifiedScope': us(self.get_value_description('MS')),
+            'modifiedConfidentialityImpact': us(self.get_value_description('MC')),
+            'modifiedIntegrityImpact': us(self.get_value_description('MI')),
+            'modifiedAvailabilityImpact': us(self.get_value_description('MA')),
+            # Scores
+            'baseScore': float(self.base_score),
+            'environmentalScore': float(self.environmental_score),
+            'temporalScore': float(self.temporal_score),
+            # Severities
+            'baseSeverity': us(base_severity),
+            'environmentalSeverity': us(temporal_severity),
+            'temporalSeverity': us(environmental_everity),
+        }
